@@ -111,7 +111,8 @@ def extract_zip_file(z, members_path, dest):
 def execute_subprocess(cmd_then_args, block=True):
     p = subprocess.Popen(
             cmd_then_args,
-            stdin=subprocess.PIPE, stdout=subprocess.PIPE, close_fds=True)
+            stdin=subprocess.PIPE, stdout=subprocess.PIPE, close_fds=True,
+            universal_newlines=True)
     if block:
         stdout, stderr = p.communicate()
         return stdout, stderr, p.returncode
@@ -127,7 +128,7 @@ class AutostartManager:
     def get_user_autostart_files():
         return glob.glob(
                     os.path.join(
-                        GLib.get_user_config_dir(), "autostart", "*.desktop")) 
+                        GLib.get_user_config_dir(), "autostart", "*.desktop"))
 
     @staticmethod
     def get_system_autostart_files():
@@ -150,14 +151,13 @@ class AutostartFile:
             raise Exception("Need either an appinfo or a file name")
 
         self._exec_cmd = exec_cmd
-        self._extra_exec_args = " %s\n" % extra_exec_args
+        if extra_exec_args:
+            self._extra_exec_args = " %s\n" % extra_exec_args
+        else:
+            self._extra_exec_args = "\n"
 
         user_autostart_dir = os.path.join(GLib.get_user_config_dir(), "autostart")
-        if not os.path.isdir(user_autostart_dir):
-            try:
-                os.makedirs(user_autostart_dir)
-            except:
-                logging.critical("Could not create autostart dir: %s" % user_autostart_dir)
+        os.makedirs(user_autostart_dir, exist_ok=True)
 
         self._user_autostart_file = os.path.join(user_autostart_dir, self._autostart_desktop_filename)
 
@@ -204,7 +204,7 @@ class AutostartFile:
             old = open(self._desktop_file, "r")
             new = open(self._user_autostart_file, "w")
 
-            for l in old.readlines():         
+            for l in old.readlines():
                 if l.startswith("Exec="):
                     if self._exec_cmd:
                         new.write("Exec=%s\n" % self._exec_cmd)
@@ -225,28 +225,28 @@ class SchemaList:
 
         if SchemaList.__list == None:
             SchemaList.__list = []
-            
+
     def get(self):
         return SchemaList.__list
-    
+
     def insert(self, key_name, schema_name):
         v = [key_name, schema_name]
         SchemaList.__list.append(v)
-    
+
     def reset(self):
         for i in SchemaList.__list:
             s = Gio.Settings(i[1])
             s.reset(i[0])
 @singleton
 class DisableExtension(GObject.GObject):
-    
+
     __gsignals__ = {
         "disable-extension": (GObject.SignalFlags.RUN_FIRST, GObject.TYPE_NONE,()),
-    }    
-    
+    }
+
     def __init__(self):
         GObject.GObject.__init__(self)
-    
+
     def disable(self):
         self.emit("disable-extension")
 
@@ -265,7 +265,7 @@ class XSettingsOverrides:
 
     def _dup_variant_as_dict(self):
         items = {}
-        for k in self._variant.keys():
+        for k in list(self._variant.keys()):
             try:
                 #variant override doesnt support .items()
                 v = self._variant[k]
@@ -308,7 +308,7 @@ class XSettingsOverrides:
 
 class Notification:
     def __init__(self, summary, body):
-        if Notify.is_initted() or Notify.init("GNOME Tweak Tool"):
+        if Notify.is_initted() or Notify.init(_("GNOME Tweaks")):
             self.notification = Notify.Notification.new(
                                     summary,
                                     body,
@@ -324,14 +324,14 @@ class Notification:
 @singleton
 class LogoutNotification:
     def __init__(self):
-        if Notify.is_initted() or Notify.init("GNOME Tweak Tool"):
+        if Notify.is_initted() or Notify.init(_("GNOME Tweaks")):
             self.notification = Notify.Notification.new(
-                                "Configuration changes require restart",
-                                "Your session needs to be restarted for settings to take effect",
+                                _("Configuration changes require restart"),
+                                _("Your session needs to be restarted for settings to take effect"),
                                 'gnome-tweak-tool')
             self.notification.add_action(
                                 "restart",
-                                "Restart Session",
+                                _("Restart Session"),
                                 self._logout, None, None)
             self.notification.set_hint(
                                 "desktop-entry",
@@ -344,9 +344,8 @@ class LogoutNotification:
         d = Gio.bus_get_sync(Gio.BusType.SESSION, None)
         proxy = Gio.DBusProxy.new_sync(
                        d,Gio.DBusProxyFlags.NONE, None,
-                       'org.gnome.SessionManager', 
-                       '/org/gnome/SessionManager', 
+                       'org.gnome.SessionManager',
+                       '/org/gnome/SessionManager',
                        'org.gnome.SessionManager',
                        None)
         proxy.Logout('(u)', 0)
-
