@@ -53,7 +53,7 @@ def build_label_beside_widget(txt, *widget, **kwargs):
     if kwargs.get("hbox"):
         hbox = kwargs.get("hbox")
     else:
-        hbox = Gtk.HBox()
+        hbox = Gtk.Box()
 
     hbox.props.spacing = UI_BOX_SPACING
     lbl = Gtk.Label(label=txt)
@@ -79,7 +79,7 @@ def build_label_beside_widget(txt, *widget, **kwargs):
     #label. By convention this is true in the great majority of cases. Settings that
     #construct their own widgets will need to set this themselves
     lbl.set_mnemonic_widget(widget[-1])
-    
+
     return hbox
 
 def build_combo_box_text(selected, *values):
@@ -126,25 +126,27 @@ def build_tight_button(stock_id):
     provider = Gtk.CssProvider()
     provider.load_from_data(data)
     # 600 = GTK_STYLE_PROVIDER_PRIORITY_APPLICATION
-    button.get_style_context().add_provider(provider, 600) 
+    button.get_style_context().add_provider(provider, 600)
     return button
 
 def adjust_schema_for_overrides(originalSchema, key, options):
     if (_shell is None):
         return originalSchema
 
-    if (_shell.mode == 'classic'):
+    if (_shell.mode == 'user'):
+        overridesSchema = "org.gnome.shell.overrides"
+        overridesFile = "org.gnome.shell.gschema.xml"
+    elif (_shell.mode == 'classic'):
         overridesSchema = "org.gnome.shell.extensions.classic-overrides"
         overridesFile = None
     else:
-        overridesSchema = "org.gnome.shell.overrides"
-        overridesFile = "org.gnome.shell.gschema.xml"
+        return originalSchema
 
     try:
         if (key in GSettingsSetting(overridesSchema, schema_filename=overridesFile).list_keys()):
             options['schema_filename'] = overridesFile
             return overridesSchema
-    except GSettingsMissingError, e:
+    except GSettingsMissingError as e:
         logging.info("GSetting missing %s" % (e.message))
 
     return originalSchema
@@ -164,7 +166,7 @@ class _GSettingsTweak(Tweak):
                 name,
                 options.get("description",self.settings.schema_get_description(key_name)),
                 **options)
-        except GSettingsMissingError, e:
+        except GSettingsMissingError as e:
             self.settings = GSettingsFakeSetting()
             Tweak.__init__(self,"","")
             self.loaded = False
@@ -217,6 +219,7 @@ class ListBoxTweakGroup(Gtk.ListBox, TweakGroup):
                         name=options['uid'])
         self.get_style_context().add_class(
                         options.get('css_class','tweak-group'))
+        self.props.margin = 20
         self.props.vexpand = False
         self.props.valign = Gtk.Align.START
 
@@ -275,14 +278,38 @@ class GSettingsSwitchTweak(Gtk.Box, _GSettingsTweak, _DependableMixin):
         w = Gtk.Switch()
         self.settings.bind(key_name, w, "active", Gio.SettingsBindFlags.DEFAULT)
 
-        build_label_beside_widget(name, w, hbox=self)
-        self.widget_for_size_group = None
-
         self.add_dependency_on_tweak(
                 options.get("depends_on"),
                 options.get("depends_how")
         )
 
+        vbox1 = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
+        vbox1.props.spacing = UI_BOX_SPACING
+        lbl = Gtk.Label(label=name)
+        lbl.props.ellipsize = Pango.EllipsizeMode.END
+        lbl.props.xalign = 0.0
+        vbox1.pack_start(lbl, True, True, 0)
+
+        if options.get("desc"):
+            description = options.get("desc")
+            lbl_desc = Gtk.Label()
+            lbl_desc.props.xalign = 0.0
+            lbl_desc.set_line_wrap(True)
+            lbl_desc.get_style_context().add_class("dim-label")
+            lbl_desc.set_markup("<span size='small'>"+GLib.markup_escape_text(description)+"</span>")
+            vbox1.pack_start(lbl_desc, True, True, 0)
+
+        vbox2 = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
+        vbox2_upper = Gtk.Box()
+        vbox2_lower = Gtk.Box()
+        vbox2.pack_start(vbox2_upper, True, True, 0)
+        vbox2.pack_start(w, False, False, 0)
+        vbox2.pack_start(vbox2_lower, True, True, 0)
+
+        self.pack_start(vbox1, True, True, 0)
+        self.pack_start(vbox2, False, False, 0)
+        self.widget_for_size_group = None
+
 class GSettingsFontButtonTweak(Gtk.Box, _GSettingsTweak, _DependableMixin):
     def __init__(self, name, schema_name, key_name, **options):
         Gtk.Box.__init__(self, orientation=Gtk.Orientation.HORIZONTAL)
@@ -324,7 +351,7 @@ class GSettingsSpinButtonTweak(Gtk.Box, _GSettingsTweak, _DependableMixin):
 
         build_label_beside_widget(name, w, hbox=self)
         self.widget_for_size_group = w
-        
+
         self.add_dependency_on_tweak(
                 options.get("depends_on"),
                 options.get("depends_how")
@@ -477,15 +504,16 @@ class DarkThemeSwitcher(Gtk.Box, Tweak):
                        _("Enable the dark theme hint for all the applications in the session"),
                        **options)
 
-        self._gtksettings = GtkSettingsManager()
+        self._gtksettings3 = GtkSettingsManager('3.0')
+        self._gtksettings4 = GtkSettingsManager('4.0')
 
         w = Gtk.Switch()
-        w.set_active(self._gtksettings.get_integer("gtk-application-prefer-dark-theme"))
-		
+        w.set_active(self._gtksettings3.get_integer("gtk-application-prefer-dark-theme"))
+
         title = _("Global Dark Theme")
-        description = _("Applications need to be restarted for change to take effect")
+        description = _("Applications need to be restarted for this change to take place.")
         w.connect("notify::active", self._on_switch_changed)
-        
+
         hbox = Gtk.Box(orientation=Gtk.Orientation.HORIZONTAL)
         hbox.props.spacing = UI_BOX_SPACING
         lbl = Gtk.Label(label=title)
@@ -493,11 +521,12 @@ class DarkThemeSwitcher(Gtk.Box, Tweak):
         lbl.props.xalign = 0.0
         hbox.pack_start(lbl, True, True, 0)
         hbox.pack_start(w, False, False, 0)
-        
+
         lbl_des = Gtk.Label()
         lbl_des.props.xalign = 0.0
-        lbl_des.set_markup("<span size='x-small'>"+GLib.markup_escape_text(description)+"</span>")
-        
+        lbl_des.get_style_context().add_class("dim-label")
+        lbl_des.set_markup("<span size='small'>"+GLib.markup_escape_text(description)+"</span>")
+
         self.pack_start(hbox, False, False, 0)
         self.pack_start(lbl_des, False, False,0)
         self.widget_for_size_group = None
@@ -506,7 +535,9 @@ class DarkThemeSwitcher(Gtk.Box, Tweak):
         active = switch.get_active()
 
         try:
-            self._gtksettings.set_integer("gtk-application-prefer-dark-theme",
+            self._gtksettings3.set_integer("gtk-application-prefer-dark-theme",
+                                          active)
+            self._gtksettings4.set_integer("gtk-application-prefer-dark-theme",
                                           active)
         except:
             self.notify_information(_("Error writing setting"))
@@ -518,10 +549,12 @@ class Title(Gtk.Box, Tweak):
         widget = Gtk.Label()
         widget.set_markup("<b>"+GLib.markup_escape_text(name)+"</b>")
         widget.props.xalign = 0.0
+        if not options.get("top"):
+            widget.set_margin_top(10)
         self.add(widget)
 
 class GSettingsSwitchTweakValue(Gtk.Box, _GSettingsTweak):
-    
+
     def __init__(self, name, schema_name, key_name, **options):
         Gtk.Box.__init__(self, orientation=Gtk.Orientation.HORIZONTAL)
         _GSettingsTweak.__init__(self, name, schema_name, key_name, **options)
@@ -529,13 +562,39 @@ class GSettingsSwitchTweakValue(Gtk.Box, _GSettingsTweak):
         sw = Gtk.Switch()
         sw.set_active(self.get_active())
         sw.connect("notify::active", self._on_toggled)
-        build_label_beside_widget(name, sw, hbox=self)
+
+        vbox1 = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
+        vbox1.props.spacing = UI_BOX_SPACING
+        lbl = Gtk.Label(label=name)
+        lbl.props.ellipsize = Pango.EllipsizeMode.END
+        lbl.props.xalign = 0.0
+        vbox1.pack_start(lbl, True, True, 0)
+
+        if options.get("desc"):
+            description = options.get("desc")
+            lbl_desc = Gtk.Label()
+            lbl_desc.props.xalign = 0.0
+            lbl_desc.set_line_wrap(True)
+            lbl_desc.get_style_context().add_class("dim-label")
+            lbl_desc.set_markup("<span size='small'>"+GLib.markup_escape_text(description)+"</span>")
+            vbox1.pack_start(lbl_desc, True, True, 0)
+
+        vbox2 = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
+        vbox2_upper = Gtk.Box()
+        vbox2_lower = Gtk.Box()
+        vbox2.pack_start(vbox2_upper, True, True, 0)
+        vbox2.pack_start(sw, False, False, 0)
+        vbox2.pack_start(vbox2_lower, True, True, 0)
+
+        self.pack_start(vbox1, True, True, 0)
+        self.pack_start(vbox2, False, False, 0)
+        self.widget_for_size_group = None
 
     def _on_toggled(self, sw, pspec):
         self.set_active(sw.get_active())
-    
+
     def set_active(self, v):
         raise NotImplementedError()
-    
+
     def get_active(self):
         raise NotImplementedError()
